@@ -653,15 +653,9 @@ H5Zfilter_avail(H5Z_filter_t id)
     /* Check args */
     if(id<0 || id>H5Z_FILTER_MAX)
         HGOTO_ERROR (H5E_ARGS, H5E_BADVALUE, FAIL, "invalid filter identification number")
- 
-    if((ret_value = H5Z_filter_avail(id)) < 0)
-    	HGOTO_ERROR(H5E_PLINE, H5E_NOTFOUND, FAIL, "unable to check the availability of the filter")
-    else if(ret_value == FALSE) {
-        const H5Z_class2_t *filter_info;
 
-        if(NULL != (filter_info = (const H5Z_class2_t *)H5PL_load(H5PL_TYPE_FILTER, (int)id)))
-        	ret_value = TRUE;
-    } /* end if */
+    if((ret_value = H5Z_filter_avail(id)) < 0)
+        HGOTO_ERROR(H5E_PLINE, H5E_NOTFOUND, FAIL, "unable to check the availability of the filter")
 
 done:
     FUNC_LEAVE_API(ret_value)
@@ -684,15 +678,21 @@ htri_t
 H5Z_filter_avail(H5Z_filter_t id)
 {
     size_t i;                   /* Local index variable */
+    const H5Z_class2_t *filter_info;
     htri_t ret_value = FALSE;   /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Is the filter already registered? */
     for(i = 0; i < H5Z_table_used_g; i++)
-	if(H5Z_table_g[i].id == id)
-	    HGOTO_DONE(TRUE)
+        if(H5Z_table_g[i].id == id)
+            HGOTO_DONE(TRUE)
 
+    if(NULL != (filter_info = (const H5Z_class2_t *)H5PL_load(H5PL_TYPE_FILTER, (int)id))) {
+        if(H5Z_register(filter_info) < 0)
+            HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, FAIL, "unable to register loaded filter")
+        HGOTO_DONE(TRUE)
+    }
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5Z_filter_avail() */
