@@ -14,7 +14,6 @@
 /*
  * Generate the binary hdf5 file for the h5copy tests
  */
-#include <stdlib.h>
 #include "hdf5.h"
 #include "H5private.h"
 
@@ -335,7 +334,7 @@ static void gent_att_compound_vlstr(hid_t loc_id)
 {
     typedef struct { /* Compound structure for the attribute */
         int i;
-        char *v;
+        const char *v;
     } s1;
     hsize_t dim[1] = {1};	/* Dimension size */
     hid_t sid = -1; 		/* Dataspace ID */
